import * as THREE from "three";
import { EventEmitter } from "events";
import Camera from "./Camera";
import Renderer from "./Renderer";
import Sizes, { type SceneSizesType } from "./utils/Sizes";
import Time from "./utils/Time";
import Resources, { type Source } from "./utils/Resources";
import Debug from "./utils/Debug";
/**
 * Initialization properties for ThreeJS
 */
export interface InitThreeProps {
    /**
     * Enable the debug mode
     *
     * @defaultValue `false`
     */
    enableDebug?: boolean;
    /**
     * Define the {@link THREE.AxesHelper} sizes.
     *
     * @remarks
     * *Deactivated if the value is `0` or `undefined`*
     * @remarks
     * *🚧 This property require the {@link InitThreeProps.enableDebug} to be `true`*
     *
     * @defaultValue `undefined`
     */
    axesSizes?: number;
    /**
     * Define the {@link THREE.GridHelper} sizes.
     *
     * @remarks
     * *Deactivated if the value is `0` or `undefined`*
     * @remarks
     * *🚧 This property require the {@link InitThreeProps.enableDebug} to be `true`*
     *
     * @defaultValue `undefined`
     */
    gridSizes?: number;
    /**
     * Define the `height` and the `width` of the scene.
     *
     * @remarks
     * *Will use the browser inner sizes if the value of each prop if `0` or `undefined`*
     *
     * @see {@link SceneSizesType}
     * @see {@link Sizes}
     *
     * @defaultValue `{undefined}`
     *
     */
    sceneSizes?: SceneSizesType;
    /**
     * Enable the scene auto resizing
     *
     * @defaultValue `true`
     */
    autoSceneResize?: boolean;
    /**
     * The camera to use for the scene.
     *
     * @remarks
     * *Will use `Perspective` camera if the value is `undefined`*
     *
     * @see {@link Camera}
     * @see {@link CameraProps}
     *
     * @defaultValue `undefined`
     */
    camera?: ConstructorParameters<typeof Camera>[0];
    /**
     * Display a mini perfective camera at the top right corner of the screen.
     *
     * @remarks
     * *🚧 This property require the {@link InitThreeProps.enableDebug} to be `true`*
     *
     * @see {@link Camera}
     * @see {@link CameraProps}
     *
     * @defaultValue `false`
     */
    withMiniCamera?: boolean;
    /**
     * A list of resources to load.
     *
     * @see {@link Source}
     * @see {@link Resources}
     *
     * @defaultValue `undefined`
     */
    sources?: Source[];
}
export declare class QuickThreejs extends EventEmitter {
    static instance?: QuickThreejs;
    static tickEvent?: () => unknown;
    static resizeEvent?: () => unknown;
    scene: THREE.Scene;
    camera: Camera;
    renderer: Renderer;
    sizes: Sizes;
    time: Time;
    resources: Resources;
    debug?: Debug;
    canvas?: HTMLCanvasElement;
    /**
     * @param props {@link InitThreeProps}
     * @param appDom The app Dom element reference
     */
    constructor(props?: InitThreeProps, appDom?: string);
    resize(): void;
    update(): void;
    destruct(): void;
}
